@@ -1,7 +1,7 @@
 """
 pyLibravatar Python module for Libravatar
 
-Copyright (C) 2011, 2013 Francois Marier <francois@libravatar.org>
+Copyright (C) 2011, 2013, 2015 Francois Marier <francois@libravatar.org>
 
 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to
@@ -165,7 +165,7 @@ def lookup_avatar_server(domain, https):
     DNS.DiscoverNameServers()
     try:
         dns_request = DNS.Request(name=service_name(domain, https),
-                                  qtype='SRV').req()
+                                  qtype='SRV', protocol='tcp').req()
     except DNS.DNSError as message:
         print("DNS Error: %s" % message)
         return None
@@ -180,7 +180,7 @@ def lookup_avatar_server(domain, https):
 
     records = []
     for answer in dns_request.answers:
-        if (not 'data' in answer) or (not answer['data']):
+        if ('data' not in answer) or (not answer['data']):
             continue
         if (not answer['typename']) or (answer['typename'] != 'SRV'):
             continue
@@ -219,7 +219,7 @@ def sanitize_target(args):
     if not target or not port:
         return (None, None)
 
-    if not re.match('^[0-9a-zA-Z\-.]+$', str(target)):
+    if not re.match('^[0-9a-zA-Z.-]+$', str(target)):
         return (None, None)
 
     try:
